#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 FloatingHex
version:              0.5
visibility:           public
id:                   FloatingHex-0.5-2vrZU3nSprJAKlqtCEerXP
key:                  FloatingHex-0.5-2vrZU3nSprJAKlqtCEerXP
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  52989aaa37713890654f990d1ef12ac0
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/FloatingHex-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/FloatingHex-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/FloatingHex-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floatinghex
hs-libraries:         HSFloatingHex-0.5-2vrZU3nSprJAKlqtCEerXP
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

